Index: uspace/srv/locsrv/locsrv.c
===================================================================
--- uspace/srv/locsrv/locsrv.c	(revision 132ab5d1e75253f9bae910b2748a4c13efe7e71f)
+++ uspace/srv/locsrv/locsrv.c	(revision 50206e9574b78ae79eedeb03577fe6a9f9bb4d09)
@@ -356,5 +356,5 @@
 	 * Get server name
 	 */
-	int rc = async_data_write_accept((void **) &server->name, true, 0,
+	errno_t rc = async_data_write_accept((void **) &server->name, true, 0,
 	    LOC_NAME_MAXLEN, 0, NULL);
 	if (rc != EOK) {
@@ -410,5 +410,5 @@
  *
  */
-static int loc_server_unregister(loc_server_t *server)
+static errno_t loc_server_unregister(loc_server_t *server)
 {
 	if (server == NULL)
@@ -471,5 +471,5 @@
 	/* Get fqsn */
 	char *fqsn;
-	int rc = async_data_write_accept((void **) &fqsn, true, 0,
+	errno_t rc = async_data_write_accept((void **) &fqsn, true, 0,
 	    LOC_NAME_MAXLEN, 0, NULL);
 	if (rc != EOK) {
@@ -599,5 +599,5 @@
 	}
 	
-	int retval = async_data_read_finalize(callid, cat->name,
+	errno_t retval = async_data_read_finalize(callid, cat->name,
 	    min(size, act_size));
 	
@@ -647,5 +647,5 @@
 	}
 	
-	int retval = async_data_read_finalize(callid, fqn,
+	errno_t retval = async_data_read_finalize(callid, fqn,
 	    min(size, act_size));
 	free(fqn);
@@ -694,5 +694,5 @@
 	}
 	
-	int retval = async_data_read_finalize(callid, svc->server->name,
+	errno_t retval = async_data_read_finalize(callid, svc->server->name,
 	    min(size, act_size));
 	
@@ -743,5 +743,5 @@
 	
 	/* Get fqsn */
-	int rc = async_data_write_accept((void **) &fqsn, true, 0,
+	errno_t rc = async_data_write_accept((void **) &fqsn, true, 0,
 	    LOC_NAME_MAXLEN, 0, NULL);
 	if (rc != EOK) {
@@ -806,5 +806,5 @@
 	
 	/* Get service name */
-	int rc = async_data_write_accept((void **) &name, true, 0,
+	errno_t rc = async_data_write_accept((void **) &name, true, 0,
 	    LOC_NAME_MAXLEN, 0, NULL);
 	if (rc != EOK) {
@@ -851,5 +851,5 @@
  * events.
  *
  * On success, answer will contain EOK int retval.
  * On failure, error code will be sent in retval.
  *
@@ -895,5 +895,5 @@
 /** Find ID for category specified by name.
  *
  * On success, answer will contain EOK int retval and service ID in arg1.
  * On failure, error code will be sent in retval.
  *
@@ -905,5 +905,5 @@
 	
 	/* Get service name */
-	int rc = async_data_write_accept((void **) &name, true, 0,
+	errno_t rc = async_data_write_accept((void **) &name, true, 0,
 	    LOC_NAME_MAXLEN, 0, NULL);
 	if (rc != EOK) {
@@ -972,5 +972,5 @@
 	size_t size;
 	size_t act_size;
-	int rc;
+	errno_t rc;
 	
 	if (!async_data_read_receive(&callid, &size)) {
@@ -1000,5 +1000,5 @@
 	fibril_mutex_unlock(&cdir.mutex);
 	
-	int retval = async_data_read_finalize(callid, id_buf, size);
+	errno_t retval = async_data_read_finalize(callid, id_buf, size);
 	free(id_buf);
 	
@@ -1047,5 +1047,5 @@
 	}
 	
-	int retval = async_data_read_finalize(callid, desc, size);
+	errno_t retval = async_data_read_finalize(callid, desc, size);
 	
 	free(desc);
@@ -1110,5 +1110,5 @@
 	}
 	
-	int retval = async_data_read_finalize(callid, desc, size);
+	errno_t retval = async_data_read_finalize(callid, desc, size);
 	
 	free(desc);
@@ -1123,5 +1123,5 @@
 	size_t size;
 	size_t act_size;
-	int rc;
+	errno_t rc;
 	
 	if (!async_data_read_receive(&callid, &size)) {
@@ -1163,5 +1163,5 @@
 	fibril_mutex_unlock(&cdir.mutex);
 	
-	int retval = async_data_read_finalize(callid, id_buf, size);
+	errno_t retval = async_data_read_finalize(callid, id_buf, size);
 	free(id_buf);
 	
@@ -1278,5 +1278,5 @@
 	catid_t cat_id;
 	service_id_t svc_id;
-	int retval;
+	errno_t retval;
 	
 	svc_id = IPC_GET_ARG1(*icall);
@@ -1531,5 +1531,5 @@
 	
 	port_id_t port;
-	int rc = async_create_port(INTERFACE_LOC_SUPPLIER,
+	errno_t rc = async_create_port(INTERFACE_LOC_SUPPLIER,
 	    loc_connection_supplier, NULL, &port);
 	if (rc != EOK) {
@@ -851,5 +851,5 @@
  * events.
  *
- * On success, answer will contain EOK int retval.
+ * On success, answer will contain EOK errno_t retval.
  * On failure, error code will be sent in retval.
  *
@@ -895,5 +895,5 @@
 /** Find ID for category specified by name.
  *
- * On success, answer will contain EOK int retval and service ID in arg1.
+ * On success, answer will contain EOK errno_t retval and service ID in arg1.
  * On failure, error code will be sent in retval.
  *
